@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 
-from .common import match1, download_urls, get_filename, parse_host, set_proxy, unset_proxy
+from .common import match1, maybe_print, download_urls, get_filename, parse_host, set_proxy, unset_proxy
 from .util import log
 from . import json_output
 import os
@@ -111,14 +111,14 @@ class VideoExtractor():
         else:
             stream = self.dash_streams[stream_id]
 
-        print("    - title:         %s" % self.title)
+        maybe_print("    - title:         %s" % self.title)
         print("       size:         %s MiB (%s bytes)" % (round(stream['size'] / 1048576, 1), stream['size']))
         print("        url:         %s" % self.url)
         print()
 
     def p(self, stream_id=None):
-        print("site:                %s" % self.__class__.name)
-        print("title:               %s" % self.title)
+        maybe_print("site:                %s" % self.__class__.name)
+        maybe_print("title:               %s" % self.title)
         if stream_id:
             # Print the stream
             print("stream:")
@@ -151,7 +151,7 @@ class VideoExtractor():
                 print("      download-url:  {}\n".format(i['url']))
 
     def p_playlist(self, stream_id=None):
-        print("site:                %s" % self.__class__.name)
+        maybe_print("site:                %s" % self.__class__.name)
         print("playlist:            %s" % self.title)
         print("videos:")
 
